@@ -7,8 +7,8 @@ SELECT
 FROM
   DHtOp
 WHERE
-  DhtOp.authored_timestamp_ms >= :from
-  AND DhtOp.authored_timestamp_ms < :to
+  DhtOp.authored_timestamp >= :from
+  AND DhtOp.authored_timestamp < :to
   AND storage_center_loc < :storage_end_loc
 UNION
 ALL
@@ -17,6 +17,6 @@ SELECT
 FROM
   DHtOp
 WHERE
-  authored_timestamp_ms >= :from
-  AND DhtOp.authored_timestamp_ms < :to
+  authored_timestamp >= :from
+  AND DhtOp.authored_timestamp < :to
   AND storage_center_loc > :storage_start_loc
